==> cianparser-0.4.23-py3-none-any.whl: cianparser/constants.py <==
BASE_LINK = "https://cian.ru/cat.php?engine_version=2&p={}&region={}"
ACCOMMODATION_TYPE_PARAMETER = "&offer_type={}"
DURATION_TYPE_PARAMETER = "&type={}"
DEAL_TYPE = "&deal_type={}"

FLOATS_NUMBERS_REG_EXPRESSION = r"[+-]? *(?:\d+(?:\.\d*)?|\.\d+)(?:[eE][+-]?\d+)?"

ROOM = "&room{}=1"
STUDIO = "&room9=1"
WITHOUT_NEIGHBORS_OF_CITY = "&with_neighbors=0"
IS_ONLY_HOMEOWNER = "&is_by_homeowner=1"

NOT_STREET_ADDRESS_ELEMENTS = {"ЖК", "м.", "мкр.", "Жилой комплекс", "Жилой Комплекс"}

STREET_TYPES = {"улица", "аллея", "бульвар", "линия", "набережная", "тракт", "тупик", "шоссе", "переулок", "проспект",
                "проезд", "раздъезд", "мост", "авеню"}

SPECIFIC_FIELDS_FOR_RENT_LONG = {"price_per_month", "commissions"}
SPECIFIC_FIELDS_FOR_RENT_SHORT = {"price_per_day"}
SPECIFIC_FIELDS_FOR_SALE = {"price", "residential_complex"}

CITIES = [
    ['Москва', '1'],
    ['Санкт-Петербург', '2'],
    ['Абакан', '4638'],
    ['Анадырь', '4648'],
    ['Архангельск', '4658'],
    ['Астрахань', '4660'],
    ['Барнаул', '4668'],
    ['Белгород', '4671'],
    ['Биробиджан', '4682'],
    ['Благовещенск', '4683'],
    ['Бронницы', '4690'],
    ['Брянск', '4691'],
    ['Великий Новгород', '4694'],
    ['Владивосток', '4701'],
    ['Владикавказ', '4702'],
    ['Владимир', '4703'],
    ['Волгоград', '4704'],
    ['Вологда', '4708'],
    ['Воронеж', '4713'],
    ['Геленджик', '4717'],
    ['Горно-Алтайск', '4719'],
    ['Грозный', '4723'],
    ['Дзержинский', '4734'],
    ['Долгопрудный', '4738'],
    ['Дубна', '4741'],
    ['Екатеринбург', '4743'],
    ['Жуковский', '4750'],
    ['Звенигород', '4756'],
    ['Иванов', '4767'],
    ['Ижевск', '4770'],
    ['Иркутск', '4774'],
    ['Йошкар-Ола', '4776'],
    ['Казань', '4777'],
    ['Калининград', '4778'],
    ['Калуга', '4780'],
    ['Кемерово', '4795'],
    ['Киров', '4800'],
    ['Коломна', '4809'],
    ['Королёв', '4813'],
    ['Красноармейск', '4817'],
    ['Краснодар', '4820'],
    ['Краснознаменск', '4822'],
    ['Красноярск', '4827'],
    ['Курган', '4834'],
    ['Курск', '4835'],
    ['Кызыл', '4837'],
    ['Липецк', '4847'],
    ['Лобня', '4848'],
    ['Лыткарино', '4851'],
    ['Магадан', '4852'],
    ['Майкоп', '4855'],
    ['Махачкала', '4857'],
    ['Мурманск', '4871'],
    ['Нальчик', '4875'],
    ['Нарьян-Мар', '4876'],
    ['Нижний Новгород', '4885'],
    ['Новороссийск', '4896'],
    ['Новокузнецк', '4894'],
    ['Новосибирск', '4897'],
    ['Омск', '4914'],
    ['Оренбург', '4915'],
    ['Орехово-Зуево', '4916'],
    ['Пенза', '4923'],
    ['Пермь', '4927'],
    ['Петрозаводск', '4930'],
    ['Петропавловск-Камчатский', '4931'],
    ['Подольск', '4935'],
    ['Протвино', '4945'],
    ['Псков', '4946'],
    ['Пущино', '4949'],
    ['Реутов', '4958'],
    ['Ростов-На-Дону', '4959'],
    ['Рошаль', '4960'],
    ['Рязань', '4963'],
    ['Салехард', '4965'],
    ['Самара', '4966'],
    ['Саранск', '4967'],
    ['Саратов', '4969'],
    ['Серпухов', '4983'],
    ['Смоленск', '4987'],
    ['Сочи', '4998'],
    ['Ставрополь', '5001'],
    ['Сургут', '5003'],
    ['Сыктывкар', '5006'],
    ['Тамбов', '5011'],
    ['Тольятти', '5015'],
    ['Томск', '5016'],
    ['Тула', '5020'],
    ['Тюмень', '5024'],
    ['Улан-Удэ', '5026'],
    ['Ульяновск', '5027'],
    ['Фрязино', '5038'],
    ['Хабаровск', '5039'],
    ['Ханты-Мансийск', '5041'],
    ['Химки', '5044'],
    ['Чебоксары', '5047'],
    ['Челябинск', '5048'],
    ['Череповец', '5050'],
    ['Черкесск', '5051'],
    ['Чита', '5053'],
    ['Электросталь', '5064'],
    ['Элиста', '5065'],
    ['Южно-Сахалинск', '5069'],
    ['Якутск', '5073'],
    ['Ярославль', '5075'],
]

OTHER_CITIES = [
    ['Азов', '174136'],
    ['Аксай', '174151'],
    ['Альметьевск', '174184'],
    ['Анапа', '174191'],
    ['Балашиха', '174292'],
    ['Бокситогорск', '174373'],
    ['Бора', '174402'],
    ['Видный', '174508'],
    ['Волоколамск', '174522'],
    ['Воскресенск', '174530'],
    ['Высоковск', '174541'],
    ['Голицын', '174573'],
    ['Дмитров', '174634'],
    ['Домодедово', '174640'],
    ['Дрезна', '174644'],
    ['Егорьевск', '174659'],
    ['Истра,174832'],
    ['Кашира,174957'],
    ['Ликино-Дулёво,175209'],
    ['Лосино-Петровский,175219'],
    ['Луховицы,175226'],
    ['Люберцы,175231'],
    ['Можайск,175349'],
    ['Мытищи,175378'],
    ['Набережные Челны,175380'],
    ['Назрань,175389'],
]

CITIES.extend(OTHER_CITIES)

==> cianparser-0.4.26-py3-none-any.whl: cianparser/constants.py <==
BASE_LINK = "https://cian.ru/cat.php?engine_version=2&p={}&region={}"
ACCOMMODATION_TYPE_PARAMETER = "&offer_type={}"
DURATION_TYPE_PARAMETER = "&type={}"
DEAL_TYPE = "&deal_type={}"

FLOATS_NUMBERS_REG_EXPRESSION = r"[+-]? *(?:\d+(?:\.\d*)?|\.\d+)(?:[eE][+-]?\d+)?"

ROOM = "&room{}=1"
STUDIO = "&room9=1"
WITHOUT_NEIGHBORS_OF_CITY = "&with_neighbors=0"
IS_ONLY_HOMEOWNER = "&is_by_homeowner=1"
HAVE_BALCONIES = "&min_balconies=1"
HAVE_LOGGIA = "&loggia=1"
MIN_HOUSE_YEAR = "&min_house_year={}"
MAX_HOUSE_YEAR = "&min_house_year={}"
MIN_PRICE = "&minprice={}"
MAX_PRICE = "&maxprice={}"
MIN_FLOOR = "&minfloor={}"
MAX_FLOOR = "&maxfloor={}"
MIN_TOTAL_FLOOR = "&minfloorn={}"
MAX_TOTAL_FLOOR = "&maxfloorn={}"

SORT_BY_PRICE_FROM_MIN_TO_MAX = "&sort=price_object_order"
SORT_BY_PRICE_FROM_MAX_TO_MIN = "&sort=total_price_desc"
SORT_BY_TOTAL_METERS_FROM_MAX_TO_MIN = "&sort=area_order"
SORT_BY_CREATION_DATA_FROM_NEWER_TO_OLDER = "&sort=creation_date_desc"
SORT_BY_CREATION_DATA_FROM_OLDER_TO_NEWER = "&sort=creation_date_asc"

IS_SORT_BY_PRICE_FROM_MIN_TO_MAX = "price_from_min_to_max"
IS_SORT_BY_PRICE_FROM_MAX_TO_MIN = "price_from_max_to_min"
IS_SORT_BY_TOTAL_METERS_FROM_MAX_TO_MIN = "total_meters_from_max_to_min"
IS_SORT_BY_CREATION_DATA_FROM_NEWER_TO_OLDER = "creation_data_from_newer_to_older"
IS_SORT_BY_CREATION_DATA_FROM_OLDER_TO_NEWER = "creation_data_from_older_to_newer"

NOT_STREET_ADDRESS_ELEMENTS = {"ЖК", "м.", "мкр.", "Жилой комплекс", "Жилой Комплекс"}

STREET_TYPES = {"улица", "аллея", "бульвар", "линия", "набережная", "тракт", "тупик", "шоссе", "переулок", "проспект",
                "проезд", "раздъезд", "мост", "авеню"}

SPECIFIC_FIELDS_FOR_RENT_LONG = {"price_per_month", "commissions"}
SPECIFIC_FIELDS_FOR_RENT_SHORT = {"price_per_day"}
SPECIFIC_FIELDS_FOR_SALE = {"price", "residential_complex"}

CITIES = [
    ['Москва', '1'],
    ['Санкт-Петербург', '2'],
    ['Абакан', '4638'],
    ['Анадырь', '4648'],
    ['Архангельск', '4658'],
    ['Астрахань', '4660'],
    ['Барнаул', '4668'],
    ['Белгород', '4671'],
    ['Биробиджан', '4682'],
    ['Благовещенск', '4683'],
    ['Бронницы', '4690'],
    ['Брянск', '4691'],
    ['Великий Новгород', '4694'],
    ['Владивосток', '4701'],
    ['Владикавказ', '4702'],
    ['Владимир', '4703'],
    ['Волгоград', '4704'],
    ['Вологда', '4708'],
    ['Воронеж', '4713'],
    ['Геленджик', '4717'],
    ['Горно-Алтайск', '4719'],
    ['Грозный', '4723'],
    ['Дзержинский', '4734'],
    ['Долгопрудный', '4738'],
    ['Дубна', '4741'],
    ['Екатеринбург', '4743'],
    ['Жуковский', '4750'],
    ['Звенигород', '4756'],
    ['Иванов', '4767'],
    ['Ижевск', '4770'],
    ['Иркутск', '4774'],
    ['Йошкар-Ола', '4776'],
    ['Казань', '4777'],
    ['Калининград', '4778'],
    ['Калуга', '4780'],
    ['Кемерово', '4795'],
    ['Киров', '4800'],
    ['Коломна', '4809'],
    ['Королёв', '4813'],
    ['Красноармейск', '4817'],
    ['Краснодар', '4820'],
    ['Краснознаменск', '4822'],
    ['Красноярск', '4827'],
    ['Курган', '4834'],
    ['Курск', '4835'],
    ['Кызыл', '4837'],
    ['Липецк', '4847'],
    ['Лобня', '4848'],
    ['Лыткарино', '4851'],
    ['Магадан', '4852'],
    ['Майкоп', '4855'],
    ['Махачкала', '4857'],
    ['Мурманск', '4871'],
    ['Нальчик', '4875'],
    ['Нарьян-Мар', '4876'],
    ['Нижний Новгород', '4885'],
    ['Новороссийск', '4896'],
    ['Новокузнецк', '4894'],
    ['Новосибирск', '4897'],
    ['Омск', '4914'],
    ['Оренбург', '4915'],
    ['Орехово-Зуево', '4916'],
    ['Пенза', '4923'],
    ['Пермь', '4927'],
    ['Петрозаводск', '4930'],
    ['Петропавловск-Камчатский', '4931'],
    ['Подольск', '4935'],
    ['Протвино', '4945'],
    ['Псков', '4946'],
    ['Пущино', '4949'],
    ['Реутов', '4958'],
    ['Ростов-На-Дону', '4959'],
    ['Рошаль', '4960'],
    ['Рязань', '4963'],
    ['Салехард', '4965'],
    ['Самара', '4966'],
    ['Саранск', '4967'],
    ['Саратов', '4969'],
    ['Серпухов', '4983'],
    ['Смоленск', '4987'],
    ['Сочи', '4998'],
    ['Ставрополь', '5001'],
    ['Сургут', '5003'],
    ['Сыктывкар', '5006'],
    ['Тамбов', '5011'],
    ['Тольятти', '5015'],
    ['Томск', '5016'],
    ['Тула', '5020'],
    ['Тюмень', '5024'],
    ['Улан-Удэ', '5026'],
    ['Ульяновск', '5027'],
    ['Фрязино', '5038'],
    ['Хабаровск', '5039'],
    ['Ханты-Мансийск', '5041'],
    ['Химки', '5044'],
    ['Чебоксары', '5047'],
    ['Челябинск', '5048'],
    ['Череповец', '5050'],
    ['Черкесск', '5051'],
    ['Чита', '5053'],
    ['Электросталь', '5064'],
    ['Элиста', '5065'],
    ['Южно-Сахалинск', '5069'],
    ['Якутск', '5073'],
    ['Ярославль', '5075'],
]

OTHER_CITIES = [
    ['Азов', '174136'],
    ['Аксай', '174151'],
    ['Альметьевск', '174184'],
    ['Анапа', '174191'],
    ['Балашиха', '174292'],
    ['Бокситогорск', '174373'],
    ['Бора', '174402'],
    ['Видное', '174508'],
    ['Волоколамск', '174522'],
    ['Воскресенск', '174530'],
    ['Высоковск', '174541'],
    ['Голицын', '174573'],
    ['Дмитров', '174634'],
    ['Домодедово', '174640'],
    ['Дрезна', '174644'],
    ['Егорьевск', '174659'],
    ['Истра', '174832'],
    ['Кашира', '174957'],
    ['Клин', '175004'],
    ['Кострома', '175050'],
    ['Котельник', '175051'],
    ['Красногорск', '175071'],
    ['Краснозаводск', '175075'],
    ['Кубинка', '175104'],
    ['Ликино-Дулёво', '175209'],
    ['Лосино-Петровский', '175219'],
    ['Луховицы', '175226'],
    ['Люберцы', '175231'],
    ['Можайск', '175349'],
    ['Мытищи', '175378'],
    ['Набережные Челны', '175380'],
    ['Назрань', '175389'],
    ['Одинцово', '175578'],
    ['Орёл', '175604'],
    ['Павловский Посад', '175635'],
    ['Пушкин', '175744'],
    ['Раменское', '175758'],
    ['Руза', '175785'],
    ['Сергиевом Посад', '175864'],
    ['Солнечногорск', '175903'],
    ['Ступино', '175996'],
    ['Талдом', '176052'],
    ['Тверь', '176083'],
    ['Уфа', '176245'],
    ['Хотьково', '176281'],
    ['Черноголовка', '176316'],
    ['Чехов', '176321'],
    ['Шатура', '176366'],
    ['Щёлково', '176401'],
    ['Электрогорск', '176405'],
    ['Яхрома', '176463'],
]

CITIES.extend(OTHER_CITIES)
